@@ -149,8 +149,8 @@ class NetcatsTool(Tool):
                 data = sock.recv(4096)
                 if len(data) > 0:
                     if self.options.tag_lines:
-                        tag = self._host
-                        data = tag + data.replace('\n', '\n' + tag + ':')
+                        tag = '\n' + self._host + ':'
+                        data = tag + data.replace('\n', '\n' + tag)
                     #
                     # Handle random exceptions on file-io
                     # in a non-standard way...
