@@ -5,8 +5,6 @@
 #
 
 
-import unittest
-
 import sys
 import os
 import os.path
@@ -391,35 +389,39 @@ def output_action_result(a, opt, _outfile):
         outfile.close()
 
 
-
 __xnet_usage__ = '''
 
     $$$ Merry Xnet! $$$
 
-The following xnet tools are available:
+The following xnet tools are available in your PATH, if installation succeeded:
+ xnet      - xnet meta tool
  iprange   - IP range enumerator
  resolv    - hostname resolver
  tcpstate  - port scanner
- netcats   - netcatish
+ netcats   - multi-peer netcat client
  webget    - web client
  sslinfo   - SSL info harvester
  iissn     - IIS shortname enumeration
 
-Analogous commands:
-$ xnet iprange ...
-$ iprange ...
+Help for some specific tool:
+ $ tcpstate --help
 
-Develop your own xnet tools:
-$ existing_xnet_tool --print-source > newtool.py
-$ vim newtool.py
-$ xnet newtool.py ...
+Analogous commands:
+ $ iprange ...
+ $ xnet iprange ...
+ $ iprange --print-source > foo.py && xnet foo.py
+
+Develop your own, or make alternative versions of existing xnet tools:
+ $ existing_xnet_tool --print-source > newtool.py
+ $ vim newtool.py
+ $ xnet newtool.py ...
 '''
 
 
 def main():
     args = sys.argv[:]
 
-    if len(args) < 2:
+    if args[1] in ('-h', '--help') or len(args) < 2:
         print __xnet_usage__
         return
 
@@ -454,8 +456,20 @@ def main():
                 ToolImplementation = val
 
     if not ToolImplementation:
+        if toolname == 'iissn':
+            from xnet.tools.iissn import IISShortnameTool as ToolImplementation
         if toolname == 'iprange':
             from xnet.tools.iprange import IPRangeTool as ToolImplementation
+        if toolname == 'netcats':
+            from xnet.tools.netcats import NetcatsTool as ToolImplementation
+        if toolname == 'resolv':
+            from xnet.tools.resolv import ResolvTool as ToolImplementation
+        if toolname == 'sslinfo':
+            from xnet.tools.sslinfo import SSLInfoTool as ToolImplementation
+        if toolname == 'tcpstate':
+            from xnet.tools.tcpstate import TcpStateTool as ToolImplementation
+        if toolname == 'webget':
+            from xnet.tools.webget import WebgetTool as ToolImplementation
 
     if not ToolImplementation:
         print 'Tool not found:', toolname
