@@ -154,6 +154,8 @@ class SSLInfoTool(Tool):
 Format variables available for %s.
 (default format is complex and not reproducable from commandline)
 
+ host        - target host
+ port        - target port
  notbefore   - not valid before
  notafter    - not valid after
  serial      - cert serial number
