@@ -43,7 +43,9 @@ class WebgetTool(Tool):
             dict(dest='https', action='store_true')),
         ('', '--host', 'specify Host header manually',
             dict(dest='host')),
-        ('', '--proxy', 'use this proxy for all protocols',
+        ('', '--method', 'specify alternative method. Examples GET, HEAD, POST, ...',
+            dict(dest='method', metavar='method')),
+        ('', '--proxy', 'broken, sorry!',
             dict(dest='proxy')),
         ('', '--code', 'only print response code',
             dict(dest='code', action='store_true')),
@@ -67,9 +69,11 @@ class WebgetTool(Tool):
 
     def __init__(self, *args, **kw):
         super(WebgetTool, self).__init__(*args, **kw)
+        if self.options.proxy:
+            msg = '--proxy is broken atm, sorry!'
+            raise Exception(msg)
         if not hasattr(self, '_http'):
-            self._http = self.__class__._http = \
-                xnet.packages.urllib3.PoolManager()
+            self._http = self.__class__._http = self._get_connection()
         self._url = None
         self._redirect_whitelist = set()
         if self.options.redirect_whitelist:
@@ -77,6 +81,12 @@ class WebgetTool(Tool):
             allowed_hosts = [h.lower() for h in allowed_hosts]
             self._redirect_whitelist = set(allowed_hosts)
 
+    def _get_connection(self):
+        if self.options.proxy:
+            return xnet.packages.urllib3.proxy_from_url(self.options.proxy)
+        else:
+            return xnet.packages.urllib3.PoolManager()
+
     def _request(self, *args, **kw):
         result = None
         done = False
@@ -89,7 +99,6 @@ class WebgetTool(Tool):
                 done = True
         return result
 
-
     def __parse__(self, line, iterator):
         '''
             only accepts plain urls atm.
@@ -129,6 +138,7 @@ class WebgetTool(Tool):
         result = {}
         _host = parse_result['host']
         _url = parse_result['url']
+        _method = self.options.method or 'GET'
         _response = None
         _body_unicode = None
         _code = None
@@ -150,7 +160,6 @@ class WebgetTool(Tool):
         if self.options.format and '{body}' in self.options.format:
             read_response = True
 
-
         done = False
         redirect_count = 0
         #
@@ -158,7 +167,7 @@ class WebgetTool(Tool):
         #
         while not done:
             try:
-                _response = self._request('GET', _url, **request_kwargs)
+                _response = self._request(_method, _url, **request_kwargs)
             except xnet.tools.WaitTimeout:
                 raise
             except xnet.packages.urllib3.exceptions.MaxRetryError, e:
